diff mbox series

[ndctl,2/2] cxl/test: allow another host bridge in cxl-topology check

Message ID 1380b5042ba3baf39777183205cc3d6974519159.1663290390.git.alison.schofield@intel.com
State Under Review
Delegated to: Vishal Verma
Headers show
Series Add CXL XOR region test | expand

Commit Message

Alison Schofield Sept. 16, 2022, 1:35 a.m. UTC
From: Alison Schofield <alison.schofield@intel.com>

Update the related count checks to allow a third CXL Host
Bridge in the cxl_test topology.

Signed-off-by: Alison Schofield <alison.schofield@intel.com>
---
 test/cxl-topology.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)
diff mbox series

Patch

diff --git a/test/cxl-topology.sh b/test/cxl-topology.sh
index 2583005fef26..11c39f61cf52 100644
--- a/test/cxl-topology.sh
+++ b/test/cxl-topology.sh
@@ -32,7 +32,7 @@  root=$(jq -r ".[] | .bus" <<< $json)
 port_sort="sort_by(.port | .[4:] | tonumber)"
 json=$($CXL list -b cxl_test -BP)
 count=$(jq ".[] | .[\"ports:$root\"] | length" <<< $json)
-((count == 2)) || err "$LINENO"
+((count == 4)) || err "$LINENO"
 
 bridge[0]=$(jq -r ".[] | .[\"ports:$root\"] | $port_sort | .[0].port" <<< $json)
 bridge[1]=$(jq -r ".[] | .[\"ports:$root\"] | $port_sort | .[1].port" <<< $json)
@@ -103,11 +103,11 @@  count=$(jq "[ $decoder_sort | .[3] |
 ((count == 1)) || err "$LINENO"
 
 
 # check that all 8 cxl_test memdevs are enabled by default and have a
 # pmem size of 256M, or 1G
 json=$($CXL list -b cxl_test -M)
 count=$(jq "map(select(.pmem_size == $pmem_size)) | length" <<< $json)
-((count == 8)) || err "$LINENO"
+((count == 16 )) || err "$LINENO"
 
 
 # check that switch ports disappear after all of their memdevs have been
@@ -103,11 +103,11 @@  count=$(jq "[ $decoder_sort | .[3] |
 
 
-# check that all 8 cxl_test memdevs are enabled by default and have a
+# check that all 16 cxl_test memdevs are enabled by default and have a
 # pmem size of 256M, or 1G
 json=$($CXL list -b cxl_test -M)